# mangbac-scraper
a managebac scraper in python using selenium

[![License: GPL v3](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)

## Installation
to install this module run the following command:

``pip install pymangebac``

After that make sure you install the [geckodriver](https://github.com/mozilla/geckodriver/releases) for your OS to PATH

## examples / usage
look at the example directory for examples.


if there are anu problems, please report them!